@@ -261,7 +261,7 @@ class Database(DatabaseInterface):
         for count in range(retry, -1, -1):
             try:
                 conn = self._connpool.getconn()
-            except PoolError:
+            except (PoolError, DatabaseOperationalError):
                 if count and not self._connpool.closed:
                     logger.info('waiting a connection')
                     time.sleep(1)
@@ -354,7 +354,7 @@ class Database(DatabaseInterface):
                         'Test failed for "%s"', db_name, exc_info=True)
                     continue
         finally:
-            self.put_connection(connection)
+            self.put_connection(connection, close=True)
 
         self.__class__._list_cache[hostname] = res
         self.__class__._list_cache_timestamp[hostname] = now
@@ -402,7 +402,7 @@ class Database(DatabaseInterface):
         try:
             return self._test(connection, hostname=hostname)
         finally:
-            self.put_connection(connection)
+            self.put_connection(connection, close=True)
 
     @classmethod
     def _test(cls, connection, hostname=None):
